SceneEntityReference

Struct SceneEntityReference 

pub struct SceneEntityReference(/* private fields */);
A unique reference for a named entity in a scene. Usually used by bevy_scene in generated code

Hashed here should allow implementing compile-time hashing in the future

The uniqueness of this is ensured by the following factors:

  • macro invocation location: filename, line and column
  • the name_id should uniquely identify a name in the individual macros scope
  • runtime, per-scope counter for each runtime call (usually from a static AtomicU64)

Implementations

Source

impl SceneEntityReference

pub fn new( (file, line, column): (&'static str, usize, usize), name_id: usize, runtime: u64, ) -> Self

Create a new SceneEntityReference from the invocation location, runtime time, and a local (per-macro) counter for names

Methods from Deref<Target = Hashed<InnerSceneEntityReference>>

pub fn hash(&self) -> u64

The pre-computed hash.