pub struct TemplateContext<'a, 'w> {
pub entity: &'a mut EntityWorldMut<'w>,
pub entity_references: &'a mut SceneEntityReferences,
}Expand description
The context used to apply the current Template. This contains a reference to the entity that the template is being
applied to (via an EntityWorldMut).
Fields
entity: &'a mut EntityWorldMut<'w>The current entity the template is being applied to
entity_references: &'a mut SceneEntityReferencesA mapping of SceneEntityReference to Entity used for resolving #Name entity references
Implementations
Sourceimpl<'a, 'w> TemplateContext<'a, 'w>
impl<'a, 'w> TemplateContext<'a, 'w>
Sourcepub fn new(
entity: &'a mut EntityWorldMut<'w>,
entity_references: &'a mut SceneEntityReferences,
) -> Self
pub fn new( entity: &'a mut EntityWorldMut<'w>, entity_references: &'a mut SceneEntityReferences, ) -> Self
Creates a new TemplateContext.
Sourcepub fn get_entity(&mut self, reference: SceneEntityReference) -> Entity
pub fn get_entity(&mut self, reference: SceneEntityReference) -> Entity
Get the entity associated with the SceneEntityReference, spawning a new one
if this is the first call with this index.
Sourcepub fn resource_mut<R: Resource<Mutability = Mutable>>(&mut self) -> Mut<'_, R>
pub fn resource_mut<R: Resource<Mutability = Mutable>>(&mut self) -> Mut<'_, R>
Retrieves a mutable reference to the given resource R.
Sourcepub fn resource_entity<R: Resource>(&self) -> Option<Entity>
pub fn resource_entity<R: Resource>(&self) -> Option<Entity>
Retrieves the entity associated with the given resource R, if it exists.