TemplateTuple

Struct TemplateTuple 

pub struct TemplateTuple<T>(pub T);
A wrapper over a tuple of Template implementations, which also implements Template. This exists because Template cannot be directly implemented for tuples of Template implementations.

Tuple Fields

0: T