pub trait SpecializeFromTemplate: Sized { }Expand description
This is used to help improve error messages related to FromTemplate specialization. Developers should generally just ignore
this trait and read the error message when they encounter it.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.